<template>
  <div>
    <BasicTable @register="registerTable">
      <template #toolbar>
        <a-button preIcon="OutR|svg" ghost color="success" @click="aoaToExcel"> 导出 </a-button>
      </template>
      <template #action="{ record }">
        <TableAction :actions="[
          {
            icon: 'clarity:info-standard-line',
            tooltip: '查看单据详情',
            onClick: handleEdit.bind(null, record),
          },
        ]" />
      </template>
    </BasicTable>
    <Loading :loading="compState.loading" :tip="compState.tip" />
    <!-- <WmsItemDrawer @register="registerDrawer" @success="handleSuccess" /> -->
  </div>
</template>
<script lang="ts" setup>
import { reactive } from 'vue';
import { aoaToSheetXlsx } from '/@/components/Excel';
import { BasicTable, useTable, TableAction } from '/@/components/Table';

import { columns, searchFormSchema } from './wms_item_sum.data';
import { getWmsItemSumByPage } from '/@/api/tigerapi/wms/wms_item';
import { useGo } from '/@/hooks/web/usePage';
import { Loading } from '/@/components/Loading';
import { useMessage } from '/@/hooks/web/useMessage';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const { createMessage } = useMessage();
const go = useGo();
const compState = reactive({
  absolute: false,
  loading: false,
  tip: '加载中...',
});
const [registerTable,{getForm,getPaginationRef}] = useTable({
  title: '库存汇总',
  api: getWmsItemSumByPage,
  columns,
  formConfig: {
    labelWidth: 120,
    schemas: searchFormSchema,
  },
  actionColumn: {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right', //undefined,
  },
  ellipsis:true,
  useSearchForm: true,
  showTableSetting: false,
  bordered: true,
  showIndexColumn: false,
});
let arr: any[] = [];
function aoaToExcel() {
  const totals = getPaginationRef().total
  if (totals < 30000) {
    arr = [];
    compState.loading = true;
    const col = getForm().getFieldsValue()
    getWmsItemSumByPage(col).then((res) => {
      res.items.forEach(element => {
        arr.push({
          '仓库': element.WH_CODE,
          '物料代码': element.ITEM_CODE,
          '物料名称': element.ITEM_NAME,
          '数量': element.ZK_QTY,
          '单位': element.UNIT
        });
      });
      const arrHeader = columns.map((column) => column.title);
      const arrData = arr.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致
      if(arr.length<30000){
        aoaToSheetXlsx({
        data: arrData,
        header: arrHeader,
        filename: '汇总报表.xlsx',
      });
      }else{
        createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
      
      compState.loading = false;

    })

  } else {
    createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
  }


}
//跳转到实时库存
function handleEdit(record: any) {
  go('/WmsItem/' + record.ITEM_CODE);
}
</script>
